#!/bin/sh
#/****************************************************************************/
#/* PSA INSTALL SCRIPT                                                       */
#/*                                      Copyright FUJITSU LIMITED 2007-2009 */
#/*                                                                          */
#/* $Name: SLINPSA-2_1_0-0 $                                                 */
#/****************************************************************************/
# Development date : Wed Dec 9 2009

#==============================================================================
# This is the script to install PSA.
# Only root is permitted to execute this script.
# This script will return as follows.
#      0 : End successfully
#      1 : Abnormal end
#==============================================================================

#--------------------------------------
# Function
#--------------------------------------

function _message_form() {
    if [ "$SVIM" == "yes" ]; then
        echo "$*" | tee -a "$LOG_FILE"
    else
        echo "$*"
    fi
}

function message_out() {
    _message_form $*
}

function error() {
    _message_form $*
}

function log() {
    message_out $*
}

function Usage() {
    _message_form 'Usage:INSTALL.sh'
    popd >/dev/null
    exit 1
}

function svim_install() {
    rpm $RPM_OPT $RPM_PACKAGES 2>&1
    echo $? > $PSA_FILE
}

#--------------------------------------
# Define Environments
#--------------------------------------
export LANG=C
PATH=/bin:/sbin:/usr/bin:/usr/sbin

LOG_FILE="/tmp/postsetup.log"
PSA_FILE="/tmp/psasetup.log"
WORK_DIR=`dirname $0`
pushd $WORK_DIR >/dev/null
DRIVER_DIR=`pwd`
DRV_NAME=`basename $DRIVER_DIR`
RPM_NET_SNMP_LIBS="RPMS2/net-snmp-libs-5.3.2.2-5.el5_3.2.i386.rpm"
RPM_GDB="RPMS2/gdb-6.5-25.el5.x86_64.rpm"

CPUTYPE=`uname -m`
if [ $CPUTYPE = "i686" ]; then
    ARCHITECTURE="i386"
elif [ $CPUTYPE = "x86_64" ]; then
    ARCHITECTURE="x86_64"
else
    error "INSTALL.sh : This package can be installed only on x86 or Intel64."
    popd >/dev/null
    exit 1
fi

#--------------------------------------
#  change current working directory.
#--------------------------------------
if [ $EUID != 0 ]; then
    error "INSTALL.sh : only root can do that."
    popd >/dev/null
    exit 1
fi

#----------------------------------------
# Options.
#--------------------------------------
SVIM="no"

if [ "$1" == "-SVIM" ] && [ $# == 1 ] ; then
    SVIM="yes"
elif ! [ $# -eq 0 ]; then
    Usage
fi

#--------------------------------------
#  Install Start.
#--------------------------------------

#
#  Driver and tool RPM Package Install
#

RESULT=0
STATUS="notinstalled"
ACTION="installation"
RPM_OPT="-ivh"

DRVRPM=`find RPMS -name "FJSVpsa*${ARCHITECTURE}.rpm" -print 2> /dev/null`
DRVRPM_COUNT=`echo "$DRVRPM" | wc -l`

if [ "$DRVRPM" == "" ] ; then
    error "RPM package was not found."
    RESULT=1
elif [ $DRVRPM_COUNT == 1 ] ; then
    RPMNAME=`basename $DRVRPM`
    PKGNAME=`rpm -qp "$DRVRPM"`
    RPM_DRVNAME=`rpm -qip ${DRVRPM} | awk '$1=="Name" {print $3}'`

    PKGNAME_OLD=`rpm -q $RPM_DRVNAME`
    if [ $? == 0 ]; then
        STATUS="installed"
        ACTION="update"
        RPM_OPT="-Fvh"
    fi

    RPM_PACKAGES="$DRVRPM"
    if [ -d "/etc/vmware" ]; then
        if ! [ -e "/usr/lib/libnetsnmp.so.10" ]; then
            RPM_PACKAGES="$RPM_NET_SNMP_LIBS $RPM_PACKAGES"
        fi

        rpm -q gdb > /dev/null
        ec=$?
        if [ "$ec" != "0" ];then
            RPM_PACKAGES="$RPM_GDB $RPM_PACKAGES"
        fi
    fi

    log "# rpm $RPM_OPT `echo $RPM_PACKAGES | sed -e "s/RPMS[/]//g"`"

    if [ "$SVIM" == "yes" ]; then
        export FJSVPSA_LOG=1
        svim_install | tee -a "$LOG_FILE"
        ec=`cat $PSA_FILE`
        rm -f $PSA_FILE > /dev/null
        unset FJSVPSA_LOG
    else
        rpm $RPM_OPT $RPM_PACKAGES; ec=$?
    fi

    if [ "$ec" != "0" ]; then
        RESULT=1
        error "$RPMNAME ${ACTION} failed."
    else
        rpm -q $PKGNAME > /dev/null
        ec=$?
        if [ $ec -eq 0 ];then
            if [ "$ACTION" == "update" ]; then
                log "$RPMNAME is updated."
            else
                log "$RPMNAME is installed."
            fi
        else
            if [ "$STATUS" != "notinstalled" ]; then
                log "new package $DRV_NAME is already installed."
            fi
        fi
    fi
else
    error "Some old files exist in \"FJSVpsa/RPMS\" directory."
    error "please retry installation after deleting old files."
    RESULT=1
fi

#--------------------------------------
#  Finish
#--------------------------------------

if [ $RESULT != 0 ];then
    error "$DRV_NAME $ACTION failed."
else
    log "$DRV_NAME $ACTION completed."
fi

popd >/dev/null
exit $RESULT
